==> openjdk-src-19.0.1.u10-3-armv7h.pkg.tar.xz: jdk.javadoc/jdk/javadoc/internal/tool/resources/javadoc_de.java <==
package jdk.javadoc.internal.tool.resources;

public final class javadoc_de extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "doclet.internal.report.bug", "Melden Sie auf der Java-Seite zum Melden von Bugs (http://bugreport.java.com) einen Bug\nf\u00FCr das javadoc-Tool, nachdem Sie in der Bugdatenbank (http://bugs.java.com) nach Duplikaten\ngesucht haben. Nehmen Sie Fehlermeldungen und die folgende Diagnose in den Bericht auf. Vielen Dank." },
            { "javadoc.class_not_found", "Klasse {0} nicht gefunden." },
            { "javadoc.err.message", "{0}" },
            { "javadoc.error.msg", "{0}: Fehler - {1}" },
            { "javadoc.fullversion", "{0} Vollversion \"{1}\"" },
            { "javadoc.note.message", "{0}" },
            { "javadoc.note.msg", "{1}" },
            { "javadoc.note.pos.msg", "{0}: {1}" },
            { "javadoc.version", "{0} {1}" },
            { "javadoc.warn.message", "{0}" },
            { "javadoc.warning.msg", "{0}: Warnung - {1}" },
            { "main.Building_tree", "Javadoc-Informationen werden erstellt..." },
            { "main.Loading_source_file", "Quelldatei {0} wird geladen..." },
            { "main.Loading_source_files_for_package", "Quelldateien werden geladen f\u00FCr Package {0}..." },
            { "main.No_modules_packages_or_classes_specified", "Keine Module, Packages oder Klassen angegeben." },
            { "main.Xusage", "" },
            { "main.Xusage.foot", "\nDies sind keine Standardoptionen, und sie k\u00F6nnen ohne Vorank\u00FCndigung ge\u00E4ndert werden." },
            { "main.assertion.error", "Assertion-Fehler: \"{0}\"" },
            { "main.bad.arg.for.filemanager.option", "ung\u00FCltiger Wert f\u00FCr Dateimanageroption {0}: \"{1}\"" },
            { "main.cannot_use_sourcepath_for_modules", "Quellpfad kann nicht f\u00FCr mehrere Module {0} verwendet werden" },
            { "main.cant.read", "{0} kann nicht gelesen werden" },
            { "main.could_not_instantiate_class", "Klasse {0} konnte nicht instanziiert werden" },
            { "main.doclet.usage.header", "\nBereitgestellt vom Doclet {0}:" },
            { "main.doclet_class_not_found", "Doclet-Klasse {0} nicht gefunden" },
            { "main.doclet_could_not_get_location", "Speicherort f\u00FCr {0} konnte nicht abgerufen werden" },
            { "main.doclet_could_not_set_location", "Speicherort f\u00FCr {0} konnte nicht festgelegt werden" },
            { "main.doclet_no_classloader_found", "Class Loader zum Laden von {0} konnte nicht abgerufen werden" },
            { "main.done_in", "[fertig in {0} ms]" },
            { "main.error", "{0} Fehler" },
            { "main.errors", "{0} Fehler" },
            { "main.fatal.error", "schwerwiegender Fehler aufgetreten: {0}" },
            { "main.file.manager.list", "FileManager-Fehler beim Auflisten von Dateien: \"{0}\"" },
            { "main.file_not_found", "Datei nicht gefunden: \"{0}\"" },
            { "main.illegal_class_name", "Ung\u00FCltiger Klassenname: \"{0}\"" },
            { "main.illegal_option_value", "Ung\u00FCltiger Optionswert: \"{0}\"" },
            { "main.illegal_package_name", "Ung\u00FCltiger Packagename: \"{0}\"" },
            { "main.internal.error", "ein interner Fehler ist aufgetreten" },
            { "main.invalid_flag", "Ung\u00FCltiges Kennzeichen: {0}" },
            { "main.malformed_locale_name", "Nicht wohlgeformter Gebietsschemaname: {0}" },
            { "main.module_not_found", "Modul {0} nicht gefunden" },
            { "main.module_not_found_on_sourcepath", "Modul {0} in Quellpfad nicht gefunden" },
            { "main.module_source_not_found", "Quelldateien f\u00FCr Modul {0} nicht gefunden" },
            { "main.more_than_one_doclet_specified_0_and_1", "Mehr als ein Doclet angegeben: ({0} und {1})." },
            { "main.no_source_files_for_package", "Keine Quelldateien f\u00FCr Package {0}" },
            { "main.not_a_doclet", "Klasse {0} ist kein g\u00FCltiges Doclet.\nHinweis: Ab JDK 13 wird die API com.sun.javadoc nicht mehr unterst\u00FCtzt." },
            { "main.only_one_argument_with_equals", "Syntax mit \"=\" kann nicht f\u00FCr Optionen verwendet werden, die mehrere Argumente erfordern" },
            { "main.opt.J.arg", "<Flag>" },
            { "main.opt.J.desc", "\u00DCbergibt <Flag> direkt an das Laufzeitsystem" },
            { "main.opt.Werror.desc", "Meldet einen Fehler beim Auftreten von Warnungen" },
            { "main.opt.Xmaxerrs.arg", "<Nummer>" },
            { "main.opt.Xmaxerrs.desc", "Legt die maximale Anzahl der zu auszugebenden Fehler fest" },
            { "main.opt.Xmaxwarns.arg", "<Nummer>" },
            { "main.opt.Xmaxwarns.desc", "Legt die maximale Anzahl der auszugebenden Warnungen fest" },
            { "main.opt.add.exports.arg", "<Modul>/<Package>=<Anderes Modul>(,<Anderes Modul>)*" },
            { "main.opt.add.exports.desc", "Gibt an, dass ein Package als aus seinem definierenden Modul\nin weitere Module oder, wenn <Anderes Modul> ALL-UNNAMED\nlautet, in alle unbenannten Module exportiert betrachtet werden soll" },
            { "main.opt.add.modules.arg", "<Modul>(,<Modul>)*" },
            { "main.opt.add.modules.desc", "Root-Module, die zus\u00E4tzlich zu den anf\u00E4nglichen Modulen\naufgel\u00F6st werden sollen, oder alle Module im Modulpfad,\nwenn <Modul> ALL-MODULE-PATH lautet." },
            { "main.opt.add.reads.arg", "<Modul>=<Anderes Modul>(,<Anderes Modul>)*" },
            { "main.opt.add.reads.desc", "Gibt weitere Module an, die als von einem angegebenen Modul angefordert\nbetrachtet werden sollen. <Anderes Modul> kann ALL-UNNAMED lauten,\num das unbenannte Modul anzufordern." },
            { "main.opt.at.arg", "<Datei>" },
            { "main.opt.at.desc", "Liest Optionen und Dateinamen aus Datei" },
            { "main.opt.bootclasspath.arg", "<Pfad>" },
            { "main.opt.bootclasspath.desc", "Setzt den Speicherort der f\u00FCr nicht modulare Releases\nverwendeten Plattformklassendateien au\u00DFer Kraft" },
            { "main.opt.breakiterator.desc", "Berechnet den ersten Satz mit BreakIterator" },
            { "main.opt.class.path.arg", "<Pfad>" },
            { "main.opt.class.path.desc", "Gibt an, wo sich die Benutzerklassendateien befinden" },
            { "main.opt.doclet.arg", "<Klasse>" },
            { "main.opt.doclet.desc", "Generiert die Ausgabe \u00FCber ein alternatives Doclet" },
            { "main.opt.docletpath.arg", "<Pfad>" },
            { "main.opt.docletpath.desc", "Gibt an, wo sich Doclet-Klassendateien befinden" },
            { "main.opt.enable.preview.desc", "Aktiviert Vorschausprachfeatures. Wird in Verbindung\nmit -source oder --release verwendet." },
            { "main.opt.encoding.arg", "<Name>" },
            { "main.opt.encoding.desc", "Quelldateicodierungsname" },
            { "main.opt.exclude.arg", "<Packageliste>" },
            { "main.opt.exclude.desc", "Liste der auszuschlie\u00DFenden Packages" },
            { "main.opt.expand.requires.arg", "<Wert>" },
            { "main.opt.expand.requires.desc", "Anweisungen im Tool zum Erweitern des zu dokumentierenden\nModulsets. Standardm\u00E4\u00DFig werden nur die Module dokumentiert,\ndie in der Befehlszeile ausdr\u00FCcklich angegeben werden. Der Wert\n\"transitive\" schlie\u00DFt zus\u00E4tzlich alle \"requires transitive\"-Abh\u00E4ngigkeiten\nder Module ein. Der Wert \"all\" schlie\u00DFt\nalle Abh\u00E4ngigkeiten der Module ein." },
            { "main.opt.extdirs.arg", "<Verzeichnisliste>" },
            { "main.opt.extdirs.desc", "Setzt den Speicherort der installierten Erweiterungen au\u00DFer Kraft" },
            { "main.opt.help.desc", "Zeigt die Befehlszeilenoptionen an und beendet" },
            { "main.opt.help.extra.desc", "Gibt eine Zusammenfassung nicht standardm\u00E4\u00DFiger Optionen aus und beendet" },
            { "main.opt.limit.modules.arg", "<Modul>(,<Modul>)*" },
            { "main.opt.limit.modules.desc", "Begrenzt die Gesamtzahl der beobachtbaren Module" },
            { "main.opt.locale.arg", "<Name>" },
            { "main.opt.locale.desc", "Zu verwendendes Gebietsschema, z.B. en_US oder en_US_WIN" },
            { "main.opt.module.arg", "<Modul>(,<Modul>)*" },
            { "main.opt.module.desc", "Dokumentiert die angegebenen Module" },
            { "main.opt.module.path.arg", "<Pfad>" },
            { "main.opt.module.path.desc", "Gibt an, wo sich die Anwendungsmodule befinden" },
            { "main.opt.module.source.path.arg", "<Pfad>" },
            { "main.opt.module.source.path.desc", "Gib an, wo sich die Eingabequelldateien f\u00FCr mehrere Module befinden" },
            { "main.opt.package.desc", "Zeigt Package-/gesch\u00FCtzte/\u00F6ffentliche Typen und Mitglieder. Zeigt\nbei benannten Modulen alle Packages und alle Moduldetails." },
            { "main.opt.patch.module.arg", "<Modul>=<Datei>(:<Datei>)*" },
            { "main.opt.patch.module.desc", "Setzt ein Modul au\u00DFer Kraft oder erweitert es mit Klassen\nund Ressourcen in JAR-Dateien oder Verzeichnissen" },
            { "main.opt.private.desc", "Zeigt alle Typen und Mitglieder. Zeigt bei benannten Modulen\nalle Packages und alle Moduldetails." },
            { "main.opt.protected.desc", "Zeigt gesch\u00FCtzte/\u00F6ffentliche Typen und Mitglieder (Standard). Zeigt\nbei benannten Modulen exportierte Packages und die API des Moduls." },
            { "main.opt.public.desc", "Zeigt nur \u00F6ffentliche Typen und Mitglieder. Zeigt bei benannten Modulen\nnur exportierte Packages und die API des Moduls." },
            { "main.opt.quiet.desc", "Zeigt keine Statusmeldungen an" },
            { "main.opt.release.arg", "<Release>" },
            { "main.opt.release.desc", "Liefert Quellkompatibilit\u00E4t mit dem angegebenen Release" },
            { "main.opt.show.members.arg", "<Wert>" },
            { "main.opt.show.members.desc", "Gibt an, welche Mitglieder (Felder, Methoden usw.) dokumentiert\nwerden, wobei der Wert \"public\", \"protected\",\n\"package\" oder \"private\" lauten kann. Der Standardwert ist \"protected\"\nund zeigt \u00F6ffentliche und gesch\u00FCtzte Mitglieder, \"public\" zeigt nur\n\u00F6ffentliche Mitglieder, \"package\" zeigt \u00F6ffentliche, gesch\u00FCtzte und\nPackagemitglieder, und \"private\" zeigt alle Mitglieder." },
            { "main.opt.show.module.contents.arg", "<Wert>" },
            { "main.opt.show.module.contents.desc", "Gibt die Dokumentationsgranularit\u00E4t von Moduldeklarationen\nan. M\u00F6gliche Werte sind \"api\" oder \"all\"." },
            { "main.opt.show.packages.arg", "<Wert>" },
            { "main.opt.show.packages.desc", "Gibt das Modul an, dessen Packages dokumentiert werden. M\u00F6gliche\nWerte sind \"exported\" oder \"all\" (exportierte oder alle Packages)." },
            { "main.opt.show.types.arg", "<Wert>" },
            { "main.opt.show.types.desc", "Gibt an, welche Typen (Klassen, Schnittstellen usw.) dokumentiert\nwerden, wobei der Wert \"public\", \"protected\",\n\"package\" oder \"private\" lauten kann. Der Standardwert ist \"protected\"\nund zeigt \u00F6ffentliche und gesch\u00FCtzte Typen, \"public\" zeigt nur\n\u00F6ffentliche Typen, \"package\" zeigt \u00F6ffentliche, gesch\u00FCtzte und\nPackagetypen, und \"private\" zeigt alle Typen." },
            { "main.opt.source.arg", "<Release>" },
            { "main.opt.source.desc", "Liefert Quellkompatibilit\u00E4t mit dem angegebenen Release" },
            { "main.opt.source.path.arg", "<Pfad>" },
            { "main.opt.source.path.desc", "Gibt an, wo sich die Quelldateien befinden" },
            { "main.opt.subpackages.arg", "<Subpackageliste>" },
            { "main.opt.subpackages.desc", "Gibt die Subpackages an, die rekursiv geladen werden sollen" },
            { "main.opt.system.arg", "<JDK>" },
            { "main.opt.system.desc", "Setzt den Speicherort der f\u00FCr modulare Releases verwendeten Systemmodule au\u00DFer Kraft" },
            { "main.opt.upgrade.module.path.arg", "<Pfad>" },
            { "main.opt.upgrade.module.path.desc", "Setzt den Speicherort der upgradef\u00E4higen Module au\u00DFer Kraft" },
            { "main.opt.verbose.desc", "Gibt Meldungen \u00FCber die Javadoc-Vorg\u00E4nge aus" },
            { "main.opt.version.desc", "Gibt Versionsinformationen aus" },
            { "main.out.of.memory", "java.lang.OutOfMemoryError: Erweitern Sie den Speicher.\nBeispiel: F\u00FCgen Sie bei JDK Classic- oder HotSpot-VMs die Option -J-Xmx\nhinzu, zum Beispiel -J-Xmx32m." },
            { "main.package_not_found", "Package {0} nicht gefunden" },
            { "main.requires_argument", "F\u00FCr die Option {0} ist ein Argument erforderlich." },
            { "main.sourcepath_does_not_contain_module", "Quellpfad enth\u00E4lt nicht Modul {0}" },
            { "main.unexpected.exception", "eine unerwartete Ausnahme wurde abgefangen: {0}" },
            { "main.unknown.error", "ein unbekannter Fehler ist aufgetreten" },
            { "main.unknown.option.for.filemanager", "Option wird von Dateimanager nicht unterst\u00FCtzt: {0}" },
            { "main.unnecessary_arg_provided", "Option {0} erfordert kein Argument" },
            { "main.usage", "Verwendung:\n    javadoc [options] [packagenames] [sourcefiles] [@files]\nmit folgenden Optionen:" },
            { "main.usage.foot", "\nIn Optionen im GNU-Stil kann \"=\" statt Leerzeichen verwendet werden, um den Namen einer Option\nvon ihrem Wert zu trennen.\n" },
            { "main.warning", "{0} Warnung" },
            { "main.warnings", "{0} Warnungen" },
            { "main.warnings.Werror", "Warnungen gefunden und -Werror angegeben" },
        };
    }
}

==> openjdk-src-23.0.1.u0-1-armv7h.pkg.tar.xz: jdk.javadoc/jdk/javadoc/internal/tool/resources/javadoc_de.java <==
package jdk.javadoc.internal.tool.resources;

public final class javadoc_de extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "doclet.internal.report.bug", "Melden Sie auf der Java-Seite zum Melden von Bugs (https://bugreport.java.com) einen Bug\nf\u00FCr das javadoc-Tool, nachdem Sie in der Bugdatenbank (https://bugs.java.com) nach Duplikaten\ngesucht haben. Nehmen Sie Fehlermeldungen und die folgende Diagnose in den Bericht auf. Vielen Dank." },
            { "javadoc.class_not_found", "Klasse {0} nicht gefunden." },
            { "javadoc.description", "HTML-Seiten von API-Dokumentation aus Java-Quelldateien generieren" },
            { "javadoc.err.message", "{0}" },
            { "javadoc.fullversion", "{0} Vollversion \"{1}\"" },
            { "javadoc.note.message", "{0}" },
            { "javadoc.version", "{0} {1}" },
            { "javadoc.warn.message", "{0}" },
            { "main.Building_tree", "Javadoc-Informationen werden erstellt..." },
            { "main.Loading_source_file", "Quelldatei {0} wird geladen..." },
            { "main.Loading_source_files_for_package", "Quelldateien werden geladen f\u00FCr Package {0}..." },
            { "main.No_modules_packages_or_classes_specified", "Keine Module, Packages oder Klassen angegeben." },
            { "main.Xusage", "" },
            { "main.Xusage.foot", "\nDies sind keine Standardoptionen, und sie k\u00F6nnen ohne Vorank\u00FCndigung ge\u00E4ndert werden." },
            { "main.assertion.error", "Assertion-Fehler: \"{0}\"" },
            { "main.bad.arg.for.filemanager.option", "ung\u00FCltiger Wert f\u00FCr Dateimanageroption {0}: \"{1}\"" },
            { "main.cannot_use_sourcepath_for_modules", "Quellpfad kann nicht f\u00FCr mehrere Module {0} verwendet werden" },
            { "main.cant.read", "{0} kann nicht gelesen werden" },
            { "main.could_not_instantiate_class", "Klasse {0} konnte nicht instanziiert werden" },
            { "main.did-you-mean", "Meinten Sie: {0}" },
            { "main.did-you-mean-one-of", "Meinten Sie eine der folgenden Optionen: {0}" },
            { "main.doclet.usage.header", "\nBereitgestellt vom Doclet {0}:" },
            { "main.doclet_class_not_found", "Doclet-Klasse {0} nicht gefunden" },
            { "main.doclet_could_not_get_location", "Speicherort f\u00FCr {0} konnte nicht abgerufen werden" },
            { "main.doclet_could_not_set_location", "Speicherort f\u00FCr {0} konnte nicht festgelegt werden" },
            { "main.doclet_no_classloader_found", "Class Loader zum Laden von {0} konnte nicht abgerufen werden" },
            { "main.done_in", "[fertig in {0} ms]" },
            { "main.error", "{0} Fehler" },
            { "main.errors", "{0} Fehler" },
            { "main.fatal.error", "schwerwiegender Fehler aufgetreten: {0}" },
            { "main.file.manager.list", "FileManager-Fehler beim Auflisten von Dateien: \"{0}\"" },
            { "main.file_not_found", "Datei nicht gefunden: \"{0}\"" },
            { "main.for-more-details-see-usage", "Weitere Einzelheiten zu den verf\u00FCgbaren Optionen finden Sie mit \"--help\" oder \"--help-extra\"" },
            { "main.illegal_class_name", "Ung\u00FCltiger Klassenname: \"{0}\"" },
            { "main.illegal_option_value", "Ung\u00FCltiger Optionswert: \"{0}\"" },
            { "main.illegal_package_name", "Ung\u00FCltiger Packagename: \"{0}\"" },
            { "main.internal.error", "ein interner Fehler ist aufgetreten" },
            { "main.invalid_flag", "Ung\u00FCltiges Kennzeichen: {0}" },
            { "main.malformed_locale_name", "Nicht wohlgeformter Gebietsschemaname: {0}" },
            { "main.module_not_found", "Modul {0} nicht gefunden" },
            { "main.module_not_found_on_sourcepath", "Modul {0} in Quellpfad nicht gefunden" },
            { "main.module_source_not_found", "Quelldateien f\u00FCr Modul {0} nicht gefunden" },
            { "main.more_than_one_doclet_specified_0_and_1", "Mehr als ein Doclet angegeben: ({0} und {1})." },
            { "main.no_source_files_for_package", "Keine Quelldateien f\u00FCr Package {0}" },
            { "main.not_a_doclet", "Klasse {0} ist kein g\u00FCltiges Doclet.\nHinweis: Ab JDK 13 wird die API com.sun.javadoc nicht mehr unterst\u00FCtzt." },
            { "main.only_one_argument_with_equals", "Syntax mit \"=\" kann nicht f\u00FCr Optionen verwendet werden, die mehrere Argumente erfordern" },
            { "main.opt.J.arg", "<Flag>" },
            { "main.opt.J.desc", "\u00DCbergibt <Flag> direkt an das Laufzeitsystem" },
            { "main.opt.Werror.desc", "Meldet einen Fehler beim Auftreten von Warnungen" },
            { "main.opt.Xmaxerrs.arg", "<Nummer>" },
            { "main.opt.Xmaxerrs.desc", "Legt die maximale Anzahl der zu auszugebenden Fehler fest" },
            { "main.opt.Xmaxwarns.arg", "<Nummer>" },
            { "main.opt.Xmaxwarns.desc", "Legt die maximale Anzahl der auszugebenden Warnungen fest" },
            { "main.opt.add.exports.arg", "<Modul>/<Package>=<Anderes Modul>(,<Anderes Modul>)*" },
            { "main.opt.add.exports.desc", "Gibt an, dass ein Package als aus seinem definierenden Modul\nin weitere Module oder, wenn <Anderes Modul> ALL-UNNAMED\nlautet, in alle unbenannten Module exportiert betrachtet werden soll" },
            { "main.opt.add.modules.arg", "<Modul>(,<Modul>)*" },
            { "main.opt.add.modules.desc", "Root-Module, die zus\u00E4tzlich zu den anf\u00E4nglichen Modulen\naufgel\u00F6st werden sollen, oder alle Module im Modulpfad,\nwenn <Modul> ALL-MODULE-PATH lautet." },
            { "main.opt.add.reads.arg", "<Modul>=<Anderes Modul>(,<Anderes Modul>)*" },
            { "main.opt.add.reads.desc", "Gibt weitere Module an, die als von einem angegebenen Modul angefordert\nbetrachtet werden sollen. <Anderes Modul> kann ALL-UNNAMED lauten,\num das unbenannte Modul anzufordern." },
            { "main.opt.at.arg", "<Datei>" },
            { "main.opt.at.desc", "Liest Optionen und Dateinamen aus Datei" },
            { "main.opt.bootclasspath.arg", "<Pfad>" },
            { "main.opt.bootclasspath.desc", "Setzt den Speicherort der f\u00FCr nicht modulare Releases\nverwendeten Plattformklassendateien au\u00DFer Kraft" },
            { "main.opt.breakiterator.desc", "Berechnet den ersten Satz mit BreakIterator" },
            { "main.opt.class.path.arg", "<Pfad>" },
            { "main.opt.class.path.desc", "Gibt an, wo sich die Benutzerklassendateien befinden" },
            { "main.opt.doclet.arg", "<Klasse>" },
            { "main.opt.doclet.desc", "Generiert die Ausgabe \u00FCber ein alternatives Doclet" },
            { "main.opt.docletpath.arg", "<Pfad>" },
            { "main.opt.docletpath.desc", "Gibt an, wo sich Doclet-Klassendateien befinden" },
            { "main.opt.enable.preview.desc", "Aktiviert Vorschausprachfeatures. Wird in Verbindung\nmit -source oder --release verwendet." },
            { "main.opt.encoding.arg", "<Name>" },
            { "main.opt.encoding.desc", "Quelldateicodierungsname" },
            { "main.opt.exclude.arg", "<Packageliste>" },
            { "main.opt.exclude.desc", "Liste der auszuschlie\u00DFenden Packages" },
            { "main.opt.expand.requires.arg", "<Wert>" },
            { "main.opt.expand.requires.desc", "Anweisungen im Tool zum Erweitern des zu dokumentierenden\nModulsets. Standardm\u00E4\u00DFig werden nur die Module dokumentiert,\ndie in der Befehlszeile ausdr\u00FCcklich angegeben werden. Der Wert\n\"transitive\" schlie\u00DFt zus\u00E4tzlich alle \"requires transitive\"-Abh\u00E4ngigkeiten\nder Module ein. Der Wert \"all\" schlie\u00DFt\nalle Abh\u00E4ngigkeiten der Module ein." },
            { "main.opt.extdirs.arg", "<Verzeichnisliste>" },
            { "main.opt.extdirs.desc", "Setzt den Speicherort der installierten Erweiterungen au\u00DFer Kraft" },
            { "main.opt.help.desc", "Zeigt die Befehlszeilenoptionen an und beendet" },
            { "main.opt.help.extra.desc", "Gibt eine Zusammenfassung nicht standardm\u00E4\u00DFiger Optionen aus und beendet" },
            { "main.opt.limit.modules.arg", "<Modul>(,<Modul>)*" },
            { "main.opt.limit.modules.desc", "Begrenzt die Gesamtzahl der beobachtbaren Module" },
            { "main.opt.locale.arg", "<Name>" },
            { "main.opt.locale.desc", "Zu verwendendes Gebietsschema, z.B. en_US oder en_US_WIN" },
            { "main.opt.module.arg", "<Modul>(,<Modul>)*" },
            { "main.opt.module.desc", "Dokumentiert die angegebenen Module" },
            { "main.opt.module.path.arg", "<Pfad>" },
            { "main.opt.module.path.desc", "Gibt an, wo sich die Anwendungsmodule befinden" },
            { "main.opt.module.source.path.arg", "<Pfad>" },
            { "main.opt.module.source.path.desc", "Gib an, wo sich die Eingabequelldateien f\u00FCr mehrere Module befinden" },
            { "main.opt.package.desc", "Zeigt Package-/gesch\u00FCtzte/\u00F6ffentliche Typen und Mitglieder. Zeigt\nbei benannten Modulen alle Packages und alle Moduldetails." },
            { "main.opt.patch.module.arg", "<Modul>=<Datei>(:<Datei>)*" },
            { "main.opt.patch.module.desc", "Setzt ein Modul au\u00DFer Kraft oder erweitert es mit Klassen\nund Ressourcen in JAR-Dateien oder Verzeichnissen" },
            { "main.opt.private.desc", "Zeigt alle Typen und Mitglieder. Zeigt bei benannten Modulen\nalle Packages und alle Moduldetails." },
            { "main.opt.protected.desc", "Zeigt gesch\u00FCtzte/\u00F6ffentliche Typen und Mitglieder (Standard). Zeigt\nbei benannten Modulen exportierte Packages und die API des Moduls." },
            { "main.opt.public.desc", "Zeigt nur \u00F6ffentliche Typen und Mitglieder. Zeigt bei benannten Modulen\nnur exportierte Packages und die API des Moduls." },
            { "main.opt.quiet.desc", "Zeigt keine Statusmeldungen an" },
            { "main.opt.release.arg", "<Release>" },
            { "main.opt.release.desc", "Liefert Quellkompatibilit\u00E4t mit dem angegebenen Release" },
            { "main.opt.show.members.arg", "<Wert>" },
            { "main.opt.show.members.desc", "Gibt an, welche Mitglieder (Felder, Methoden usw.) dokumentiert\nwerden, wobei der Wert \"public\", \"protected\",\n\"package\" oder \"private\" lauten kann. Der Standardwert ist \"protected\"\nund zeigt \u00F6ffentliche und gesch\u00FCtzte Mitglieder, \"public\" zeigt nur\n\u00F6ffentliche Mitglieder, \"package\" zeigt \u00F6ffentliche, gesch\u00FCtzte und\nPackagemitglieder, und \"private\" zeigt alle Mitglieder." },
            { "main.opt.show.module.contents.arg", "<Wert>" },
            { "main.opt.show.module.contents.desc", "Gibt die Dokumentationsgranularit\u00E4t von Moduldeklarationen\nan. M\u00F6gliche Werte sind \"api\" oder \"all\"." },
            { "main.opt.show.packages.arg", "<Wert>" },
            { "main.opt.show.packages.desc", "Gibt das Modul an, dessen Packages dokumentiert werden. M\u00F6gliche\nWerte sind \"exported\" oder \"all\" (exportierte oder alle Packages)." },
            { "main.opt.show.types.arg", "<Wert>" },
            { "main.opt.show.types.desc", "Gibt an, welche Typen (Klassen, Schnittstellen usw.) dokumentiert\nwerden, wobei der Wert \"public\", \"protected\",\n\"package\" oder \"private\" lauten kann. Der Standardwert ist \"protected\"\nund zeigt \u00F6ffentliche und gesch\u00FCtzte Typen, \"public\" zeigt nur\n\u00F6ffentliche Typen, \"package\" zeigt \u00F6ffentliche, gesch\u00FCtzte und\nPackagetypen, und \"private\" zeigt alle Typen." },
            { "main.opt.source.arg", "<Release>" },
            { "main.opt.source.desc", "Liefert Quellkompatibilit\u00E4t mit dem angegebenen Release" },
            { "main.opt.source.path.arg", "<Pfad>" },
            { "main.opt.source.path.desc", "Gibt an, wo sich die Quelldateien befinden" },
            { "main.opt.subpackages.arg", "<Subpackageliste>" },
            { "main.opt.subpackages.desc", "Gibt die Subpackages an, die rekursiv geladen werden sollen" },
            { "main.opt.system.arg", "<JDK>" },
            { "main.opt.system.desc", "Setzt den Speicherort der f\u00FCr modulare Releases verwendeten Systemmodule au\u00DFer Kraft" },
            { "main.opt.upgrade.module.path.arg", "<Pfad>" },
            { "main.opt.upgrade.module.path.desc", "Setzt den Speicherort der upgradef\u00E4higen Module au\u00DFer Kraft" },
            { "main.opt.verbose.desc", "Gibt Meldungen \u00FCber die Javadoc-Vorg\u00E4nge aus" },
            { "main.opt.version.desc", "Gibt Versionsinformationen aus" },
            { "main.out.of.memory", "java.lang.OutOfMemoryError: Erweitern Sie den Speicher.\nBeispiel: F\u00FCgen Sie bei JDK Classic- oder HotSpot-VMs die Option -J-Xmx\nhinzu, zum Beispiel -J-Xmx32m." },
            { "main.package_not_found", "Package {0} nicht gefunden" },
            { "main.requires_argument", "F\u00FCr die Option {0} ist ein Argument erforderlich." },
            { "main.sourcepath_does_not_contain_module", "Quellpfad enth\u00E4lt nicht Modul {0}" },
            { "main.unexpected.exception", "eine unerwartete Ausnahme wurde abgefangen: {0}" },
            { "main.unknown.error", "ein unbekannter Fehler ist aufgetreten" },
            { "main.unknown.option.for.filemanager", "Option wird von Dateimanager nicht unterst\u00FCtzt: {0}" },
            { "main.unnecessary_arg_provided", "Option {0} erfordert kein Argument" },
            { "main.usage", "Verwendung:\n    javadoc [options] [packagenames] [sourcefiles] [@files]\nmit folgenden Optionen:" },
            { "main.usage.foot", "\nIn Optionen im GNU-Stil kann \"=\" statt Leerzeichen verwendet werden, um den Namen einer Option\nvon ihrem Wert zu trennen.\n" },
            { "main.warning", "{0} Warnung" },
            { "main.warnings", "{0} Warnungen" },
            { "main.warnings.Werror", "Warnungen gefunden und -Werror angegeben" },
        };
    }
}
